diff --git a/lib/public/iurlgenerator.php b/lib/public/iurlgenerator.php
index afdf1b6f299af879769faa39c64fe0a7e62ec4c9..dbbd8a3bb639c7560a470364d65a98be00ba3977 100644
--- a/lib/public/iurlgenerator.php
+++ b/lib/public/iurlgenerator.php
@@ -42,6 +42,14 @@ interface IURLGenerator {
 	 */
 	public function linkToRoute($routeName, $arguments = array());
 
+	/**
+	 * Returns the absolute URL for a route
+	 * @param string $routeName the name of the route
+	 * @param array $arguments an array with arguments which will be filled into the url
+	 * @return string the absolute url
+	 */
+	public function linkToRouteAbsolute($routeName, $arguments = array());
+
 	/**
 	 * Returns an URL for an image or file
 	 * @param string $appName the name of the app
diff --git a/lib/private/urlgenerator.php b/lib/private/urlgenerator.php
index af5d977eeabb2709821d2074a64076cdb137c186..f5ec9803edb14e4cb6e3834b131421b218fcd138 100644
--- a/lib/private/urlgenerator.php
+++ b/lib/private/urlgenerator.php
@@ -35,13 +35,26 @@ class URLGenerator implements IURLGenerator {
 	 * @internal param array $args with param=>value, will be appended to the returned url
 	 * @return string the url
 	 *
 	 * Returns a url to the given app and file.
 	 */
 	public function linkToRoute($route, $parameters = array()) {
 		$urlLinkTo = \OC::$server->getRouter()->generate($route, $parameters);
 		return $urlLinkTo;
 	}
 
+	/**
+	 * Creates an absolute url using a defined route
+	 * @param string $route
+	 * @param array $parameters
+	 * @internal param array $args with param=>value, will be appended to the returned url
+	 * @return string the url
+	 *
+	 * Returns an absolute url to the given route.
+	 */
+	public function linkToRouteAbsolute($routeName, $arguments = array()) {
+		return $this->getAbsoluteURL($this->linkToRoute($routeName, $arguments));
+	}
+
 	/**
 	 * Creates an url
 	 * @param string $app app
@@ -35,13 +35,26 @@ class URLGenerator implements IURLGenerator {
 	 * @return string the url
 	 *
-	 * Returns a url to the given app and file.
+	 * Returns a url to the given route.
 	 */
 	public function linkToRoute($route, $parameters = array()) {